@@ -368,7 +368,7 @@ def register_transforms():
 
     # Add mirror transform for FlyWire
     # These landmarks were created by xforming those for FAFB14 to FlyWire space
-    fp = os.path.join(data_filepath, 'FlyWire_mirror_landmarks.csv')
+    fp = os.path.join(data_filepath, 'FLYWIRE_mirror_landmarks.csv')
     lm = pd.read_csv(fp)
     tr = transforms.TPStransform(lm[['x_flip', 'y_flip', 'z_flip']].values,
                                  lm[['x_mirr', 'y_mirr', 'z_mirr']].values)
@@ -392,6 +392,28 @@ def register_transforms():
                                            target='FANCnm',
                                            transform_type='bridging')
 
+    # Add a male CNS <-> FAFB transform
+    fp = os.path.join(data_filepath, 'maleCNS_brain_FAFB_landmarks_nm.csv')
+    lm = pd.read_csv(fp)
+    tr = transforms.TPStransform(lm[['fafb_x', 'fafb_y', 'fafb_z']].values,
+                                 lm[['cns_x', 'cns_y', 'cns_z']].values)
+    transforms.registry.register_transform(transform=tr,
+                                           source='FAFB14',
+                                           target='JRCFIB2022M',
+                                           transform_type='bridging')
+    tr = transforms.AliasTransform()
+    transforms.registry.register_transform(transform=tr,
+                                           source='JRCFIB2022M',
+                                           target='JRCFIB2022Mnm',
+                                           transform_type='bridging')
+
+    # Add transform between voxel and nm space
+    tr = transforms.AffineTransform(np.diag([8, 8, 8, 1]))
+    transforms.registry.register_transform(transform=tr,
+                                           source='JRCFIB2022Mraw',
+                                           target='JRCFIB2022M',
+                                           transform_type='bridging')
+
     # Add FANC mirror transform based on subsampling a FANC -> MANCsym transform
     fp = os.path.join(data_filepath, 'FANC_mirror_landmarks.csv')
     lm = pd.read_csv(fp)
